@@ -11,7 +11,6 @@ from time import sleep
 from six import print_
 
 from django.test import TestCase
-from django.contrib.auth.models import User
 from django.test import RequestFactory
 from django.core.management import call_command
 from django.test import LiveServerTestCase
@@ -30,6 +29,7 @@ from dash.utils import get_occupied_cells, get_user_plugins
 from dash.models import DashboardEntry
 from dash.management.commands import dash_sync_plugins
 from dash.settings import WAIT_BETWEEN_TEST_STEPS, WAIT_AT_TEST_END
+from dash.compat import User
 
 DASH_TEST_USER_USERNAME = 'test_admin'
 DASH_TEST_USER_PASSWORD = 'test'
