@@ -1,3 +1,4 @@
+__title__ = 'dash.utils'
 __author__ = 'Artur Barseghyan <artur.barseghyan@gmail.com>'
 __copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
@@ -71,7 +72,7 @@ def get_user_plugins(user):
 
     return registered_plugins
 
-def get_user_plugin_uids():
+def get_user_plugin_uids(user):
     """
     Gets a list of user plugin uids as a list . If not yet autodiscovered, autodiscovers them.
 
@@ -80,7 +81,7 @@ def get_user_plugin_uids():
     ensure_autodiscover()
 
     if not RESTRICT_PLUGIN_ACCESS or getattr(user, 'is_superuser', False):
-        return get_registered_plugin_keys()
+        return get_registered_plugin_uids()
 
     registered_plugins = []
 
